imageUrl property
An optional image URL. When set, the image is loaded with an initials fallback while loading or on error.
Implementation
final String? imageUrl;
An optional image URL. When set, the image is loaded with an initials fallback while loading or on error.
final String? imageUrl;