DsColorBrand3 class

Tredje merkevarefarge — se DsColor.brand3.

Inheritance

Constructors

DsColorBrand3()
Oppretter merkevarefargerollen brand3.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited