DsColorCustom class

En egendefinert fargerolle identifisert med en key, for skalaer som ikke er en av de ni innebygde rollene. Opprettes via DsColor.custom.

Inheritance

Constructors

DsColorCustom(String key)
Oppretter en egendefinert fargerolle med nøkkelen key.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
Nøkkelen som identifiserer den egendefinerte fargeskalaen.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override