DsColorScheme class
Named set of DsColorScales for semantic and brand colors.
Each scale (accent, neutral, brand1–3, success, danger, warning, info) provides a full 16-step palette. Use resolve to map a DsColor to its scale.
Constructors
-
DsColorScheme({required DsColorScale accent, required DsColorScale neutral, required DsColorScale brand1, required DsColorScale brand2, required DsColorScale brand3, required DsColorScale success, required DsColorScale danger, required DsColorScale warning, required DsColorScale info, Map<
String, DsColorScale> custom = const {}}) -
const
Properties
- accent → DsColorScale
-
final
- brand1 → DsColorScale
-
final
- brand2 → DsColorScale
-
final
- brand3 → DsColorScale
-
final
-
custom
→ Map<
String, DsColorScale> -
final
- danger → DsColorScale
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- info → DsColorScale
-
final
- neutral → DsColorScale
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → DsColorScale
-
final
- warning → DsColorScale
-
final
Methods
-
copyWith(
{DsColorScale? accent, DsColorScale? neutral, DsColorScale? brand1, DsColorScale? brand2, DsColorScale? brand3, DsColorScale? success, DsColorScale? danger, DsColorScale? warning, DsColorScale? info, Map< String, DsColorScale> ? custom}) → DsColorScheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
DsColor color) → DsColorScale -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override