DsSeverity enum

Alvorlighetsgrad for tilbakemeldingskomponenter (f.eks. DsAlert).

Speiler Designsystemets data-color-bruk for varsler.

Inheritance
Available extensions

Values

info → const DsSeverity

Informasjon — nøytral melding.

warning → const DsSeverity

Advarsel — krever oppmerksomhet, men ikke kritisk.

success → const DsSeverity

Suksess — bekrefter at en handling lyktes.

danger → const DsSeverity

Fare — feil eller kritisk tilstand.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DsSeverity>
A constant List of the values in this enum, in order of their declaration.