DsThemeDigdir class

Built-in Digdir theme with colors from designsystemet.no.

These values are sourced from the official Digdir theme. For custom themes, use the code generator: dart run designsystemet_flutter:generate

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dark() DsThemeData
light() DsThemeData