DsSkeleton class
En plassholder-lasteindikator med en pulserende skimmer-animasjon.
Støtter tekst-, sirkel- og rektangelvarianter. Respekterer plattformens reduser-bevegelse-innstilling.
Som i Designsystemet er plassholderen som standard nøytral grå
(neutral-skalaens surface-tinted-token). Bruk color kun når du
bevisst ønsker en tonet skjelettfarge.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DsSkeleton
Constructors
- DsSkeleton({Key? key, DsSkeletonVariant? variant, double? width, double? height, double? borderRadius, DsColor? color, String? label})
-
const
Properties
- borderRadius → double?
-
Eksplisitt hjørneradius. Faller tilbake til variantens standardverdi.
final
- color → DsColor?
-
Valgfri overstyring av fargeskalaen plassholderen tegnes fra.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Eksplisitt høyde. Faller tilbake til variantens standardverdi.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
Valgfri tilgjengelighetsetikett som annonseres av skjermlesere.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → DsSkeletonVariant?
-
Variant som styrer standarddimensjoner og hjørneradius.
final
- width → double?
-
Eksplisitt bredde. Faller tilbake til variantens standardverdi.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DsSkeleton> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited