DsSortDirection enum
Sorteringstilstand for en sorterbar tabellkolonne, speiler React-attributtet
aria-sort.
Values
- none → const DsSortDirection
-
Ingen sortering — nøytral indikator (
aria-sort="none"). - ascending → const DsSortDirection
-
Stigende sortering (
aria-sort="ascending"). - descending → const DsSortDirection
-
Synkende sortering (
aria-sort="descending"). - other → const DsSortDirection
-
Sortert etter et ikke-monotont kriterium (
aria-sort="other"). Finnes foraria-sort-paritet med Designsystemet og tegner med vilje ingen-indikator-visningen — det er ikke en uimplementert tilstand.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DsSortDirection> - A constant List of the values in this enum, in order of their declaration.