DsTypography class
Typography token set generated from Designsystemet font-size and line-height scales.
Provides heading (2xl–2xs), body, body-short, and body-long text styles. Create an instance with DsTypography.create specifying the base font size.
Constructors
- DsTypography.create({String fontFamily = 'Inter', required double baseFontSize})
-
factory
Properties
- bodyLg → TextStyle
-
final
- bodyLongLg → TextStyle
-
final
- bodyLongMd → TextStyle
-
final
- bodyLongSm → TextStyle
-
final
- bodyLongXl → TextStyle
-
final
- bodyLongXs → TextStyle
-
final
- bodyMd → TextStyle
-
final
- bodyShortLg → TextStyle
-
final
- bodyShortMd → TextStyle
-
final
- bodyShortSm → TextStyle
-
final
- bodyShortXl → TextStyle
-
final
- bodyShortXs → TextStyle
-
final
- bodySm → TextStyle
-
final
- bodyXl → TextStyle
-
final
- bodyXs → TextStyle
-
final
- fontFamily → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading2xl → TextStyle
-
final
- heading2xs → TextStyle
-
final
- headingLg → TextStyle
-
final
- headingMd → TextStyle
-
final
- headingSm → TextStyle
-
final
- headingXl → TextStyle
-
final
- headingXs → TextStyle
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited